aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorRoeland Jago Douma <roeland@famdouma.nl>2018-02-21 19:46:29 +0100
committerRoeland Jago Douma <roeland@famdouma.nl>2018-02-21 19:46:29 +0100
commit2b0d64022552f6f5bb0ad64a3df8f93c60b05736 (patch)
tree893a2e74c42f8b454003202deff2b91cdea84593
parent541056f6c284953a0435d180b8620b55e344a5f4 (diff)
downloadnextcloud-server-2b0d64022552f6f5bb0ad64a3df8f93c60b05736.tar.gz
nextcloud-server-2b0d64022552f6f5bb0ad64a3df8f93c60b05736.zip
Proper closure for function
Signed-off-by: Roeland Jago Douma <roeland@famdouma.nl>
-rw-r--r--lib/private/L10N/L10N.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/private/L10N/L10N.php b/lib/private/L10N/L10N.php
index 5e74b25a1c2..f771a99e5d0 100644
--- a/lib/private/L10N/L10N.php
+++ b/lib/private/L10N/L10N.php
@@ -192,9 +192,9 @@ class L10N implements IL10N {
* Returnsed function accepts the argument $n
*
* Called by \OC_L10N_String
* @return string the plural form function
*/
- public function getPluralFormFunction(): string {
+ public function getPluralFormFunction(): \Closure {
if (\is_null($this->pluralFormFunction)) {
$lang = $this->getLanguageCode();
$this->pluralFormFunction = function($n) use ($lang) {
@@ -192,9 +192,9 @@ class L10N implements IL10N {
*
* Called by \OC_L10N_String
- * @return string the plural form function
+ * @return \Closure the plural form function
*/